Module border

Module border 

Game Boy-style tile border rendering.

A Border draws a bordered rectangle using configurable tile indices. Each of the 4 corners, 4 edge segments, and the fill area can use independent tile IDs. When no tile style is set (tiles is None), the entire rectangle is filled with a solid background color.

Structs

Border
A Game Boy-style bordered rectangle.
BorderTiles
Tile indices for a Game Boy-style box border.