Module renderer

Module renderer 

Functions

render_layout
Render a screen, first clearing to the theme background. Use for full-screen menus (main, options, stats, …).
render_layout_no_clear
Render a screen WITHOUT clearing — for overlays drawn on top of an existing scene (e.g. the battle action menu over the battle sprites).