pub struct TileCache { /* private fields */ }Expand description
Implementations
Sourceimpl TileCache
impl TileCache
pub fn new() -> Self
Sourcepub fn ensure(&mut self, tileset: &TileSet, palette: &Palette)
pub fn ensure(&mut self, tileset: &TileSet, palette: &Palette)
Populate the cache from a tileset and palette, unless already valid.
Sourcepub fn ensure_with_format<C: ColorIndex>(
&mut self,
tileset: &TileSet,
palette: &Palette<C>,
)
pub fn ensure_with_format<C: ColorIndex>( &mut self, tileset: &TileSet, palette: &Palette<C>, )
Populate the cache from a tileset and palette using a generic ColorIndex.
Unlike ensure, this method is format-aware:
TileFormat::FullColor: usesTileSet::get_rgbadirectly — no palette lookup.TileFormat::Gb2bpp/TileFormat::Gba4bpp: appliespalette.color(C::from_u8(...)).
Sourcepub fn invalidate(&mut self)
pub fn invalidate(&mut self)
Invalidate the cache so the next ensure rebuilds it.