Functions
- render_
layout - Render a screen, first clearing to the theme background. Use for full-screen menus (main, options, stats, …).
- render_
layout_ no_ clear - Render a screen WITHOUT clearing — for overlays drawn on top of an existing scene (e.g. the battle action menu over the battle sprites).